translate.storage.qph

Package translate :: Package storage :: Module qph |
[hide private]
[frames] | no frames]

# Module qph

source code

Module for handling Qt Phrase Book (.qph) files.

Extract from the Qt Linguist Manual: Translators: .qph Qt Phrase Book Files are human-readable XML files containing standard phrases and their translations. These files are created and updated by Qt Linguist and may be used by any number of projects and applications.

A DTD to define the format does not seem to exist, but the following code provides the reference implementation for the Qt Linguist product.

Classes | [hide private]
| QphUnit A single term in the qph file.
| QphFile Class representing a QPH file store.

Imports: lisa, etree